Index: detail/core/linker.hpp
===================================================================
--- detail/core/linker.hpp	(revision 9)
+++ detail/core/linker.hpp	(working copy)
@@ -22,7 +22,13 @@
 #include <typeinfo>
 #include <boost/shared_ptr.hpp>
 #include <boost/type_traits/is_same.hpp>
-#include <boost/spirit/fusion/algorithm/for_each.hpp>
+
+#if defined BOOST_XPRESSIVE_FUSION_V2
+#	include <boost/fusion/algorithm/iteration/for_each.hpp>
+#else
+#	include <boost/spirit/fusion/algorithm/for_each.hpp>
+#endif // BOOST_XPRESSIVE_FUSION_V2
+
 #include <boost/xpressive/detail/detail_fwd.hpp>
 #include <boost/xpressive/detail/dynamic/matchable.hpp>
 #include <boost/xpressive/detail/core/matchers.hpp>
@@ -255,7 +261,11 @@
       , xpression_peeker<Char> &peeker
     )
     {
-        fusion::for_each(alternates.cast(), alt_link_pred(*this, peeker, next));
+#		if defined BOOST_XPRESSIVE_FUSION_V2
+        fusion::for_each(alternates.derived(), alt_link_pred(*this, peeker, next));
+#		else
+		fusion::for_each(alternates.cast(), alt_link_pred(*this, peeker, next));
+#		endif //BOOST_XPRESSIVE_FUSION_V2
     }
 
     template<typename Traits>
Index: detail/core/matcher/alternate_matcher.hpp
===================================================================
--- detail/core/matcher/alternate_matcher.hpp	(revision 9)
+++ detail/core/matcher/alternate_matcher.hpp	(working copy)
@@ -26,8 +26,14 @@
 #endif
 
 #include <boost/shared_ptr.hpp>
-#include <boost/spirit/fusion/sequence/range.hpp>
-#include <boost/spirit/fusion/algorithm/for_each.hpp>
+#if defined BOOST_XPRESSIVE_FUSION_V2
+#	include <boost/fusion/sequence/view/iterator_range.hpp>
+#	include <boost/fusion/algorithm/iteration/for_each.hpp>
+#else
+#	include <boost/spirit/fusion/sequence/range.hpp>
+#	include <boost/spirit/fusion/algorithm/for_each.hpp>
+#endif //BOOST_XPRESSIVE_FUSION_V2
+
 #include <boost/xpressive/detail/detail_fwd.hpp>
 #include <boost/xpressive/detail/core/quant_style.hpp>
 #include <boost/xpressive/detail/core/state.hpp>
@@ -88,17 +94,31 @@
     )
     {
         typedef alt_match_pred<BidiIter, Next> alt_match_pred;
+#		if defined BOOST_XPRESSIVE_FUSION_V2        
+        return fusion::any(alternates.derived(), alt_match_pred(state));
+#		else
         return fusion::any(alternates.cast(), alt_match_pred(state));
+#		endif //BOOST_XPRESSIVE_FUSION_V2
+		
     }
 
     ///////////////////////////////////////////////////////////////////////////////
     // make_range
+#	if defined BOOST_XPRESSIVE_FUSION_V2        
     template<typename Begin, typename End>
-    inline fusion::range<Begin, End> make_range(Begin const &begin, End const &end)
+    inline fusion::iterator_range<Begin, End> make_range(Begin const &begin, End const &end)
     {
-        return fusion::range<Begin, End>(begin, end);
+        return fusion::iterator_range<Begin, End>(begin, end);
     }
+#	else
+	template<typename Begin, typename End>
+	inline fusion::range<Begin, End> make_range(Begin const &begin, End const &end)
+	{
+		return fusion::range<Begin, End>(begin, end);
+	}		
+#	endif //BOOST_XPRESSIVE_FUSION_V2
 
+
     ///////////////////////////////////////////////////////////////////////////////
     // alt_get_width_pred
     //
@@ -152,12 +172,23 @@
     )
     {
         typedef alt_get_width_pred<BidiIter> alt_get_width_pred;
+        
+#		if defined BOOST_XPRESSIVE_FUSION_V2
+        std::size_t width = (*fusion::begin(alternates.derived())).get_width(state);
+        fusion::for_each
+        (
+            make_range(fusion::next(fusion::begin(alternates.derived())), fusion::end(alternates.derived()))
+          , alt_get_width_pred(state, &width)
+        );
+#		else
         std::size_t width = (*fusion::begin(alternates.cast())).get_width(state);
         fusion::for_each
         (
             make_range(fusion::next(fusion::begin(alternates.cast())), fusion::end(alternates.cast()))
           , alt_get_width_pred(state, &width)
         );
+#		endif //BOOST_XPRESSIVE_FUSION_V2
+
         return width;
     }
 
Index: detail/static/productions/alt_compilers.hpp
===================================================================
--- detail/static/productions/alt_compilers.hpp	(revision 9)
+++ detail/static/productions/alt_compilers.hpp	(working copy)
@@ -9,6 +9,11 @@
 #define BOOST_XPRESSIVE_DETAIL_STATIC_PRODUCTIONS_ALT_COMPILERS_HPP_EAN_10_04_2005
 
 #include <boost/version.hpp>
+
+#if defined BOOST_XPRESSIVE_FUSION_V2
+#	include <boost/fusion/sequence/generation/make_cons.hpp>
+#endif //BOOST_XPRESSIVE_FUSION_V2
+
 #include <boost/xpressive/detail/detail_fwd.hpp>
 #include <boost/xpressive/proto/proto.hpp>
 #include <boost/xpressive/proto/compiler/fold.hpp>
Index: detail/utility/any.hpp
===================================================================
--- detail/utility/any.hpp	(revision 9)
+++ detail/utility/any.hpp	(working copy)
@@ -13,8 +13,11 @@
 #if BOOST_VERSION >= 103300
 
 // In Boost 1.33+, we have a cons list in Fusion, so just include it.
-# include <boost/spirit/fusion/algorithm/any.hpp>
-
+#	if defined BOOST_XPRESSIVE_FUSION_V2
+#		include <boost/fusion/algorithm/query/any.hpp>
+#	else
+#		include <boost/spirit/fusion/algorithm/any.hpp>
+#	endif //BOOST_XPRESSIVE_FUSION_V2
 #else
 
 # include <boost/spirit/fusion/sequence/begin.hpp>
Index: detail/utility/cons.hpp
===================================================================
--- detail/utility/cons.hpp	(revision 9)
+++ detail/utility/cons.hpp	(working copy)
@@ -13,8 +13,11 @@
 #if BOOST_VERSION >= 103300
 
 // In Boost 1.33+, we have a cons list in Fusion, so just include it.
-# include <boost/spirit/fusion/sequence/cons.hpp>
-
+#	if defined BOOST_XPRESSIVE_FUSION_V2
+#		include <boost/fusion/sequence/container/list/cons.hpp>
+#	else
+#		include <boost/spirit/fusion/sequence/cons.hpp>
+#	endif //BOOST_XPRESSIVE_FUSION_V2
 #else
 
 // For earlier versions of Boost, put the definition of cons here
Index: proto/op_base.hpp
===================================================================
--- proto/op_base.hpp	(revision 9)
+++ proto/op_base.hpp	(working copy)
@@ -22,7 +22,13 @@
 #include <boost/preprocessor/repetition/repeat_from_to.hpp>
 #include <boost/type_traits/is_same.hpp>
 #include <boost/type_traits/is_base_and_derived.hpp>
-#include <boost/spirit/fusion/sequence/tuple.hpp>
+
+#if defined BOOST_XPRESSIVE_FUSION_V2
+#	include <boost/fusion/tuple/tuple.hpp>
+#else
+#	include <boost/spirit/fusion/sequence/tuple.hpp>
+#endif //BOOST_XPRESSIVE_FUSION_V2
+
 #include <boost/xpressive/proto/proto_fwd.hpp>
 #include <boost/xpressive/proto/arg_traits.hpp>
 
Index: proto/proto_fwd.hpp
===================================================================
--- proto/proto_fwd.hpp	(revision 9)
+++ proto/proto_fwd.hpp	(working copy)
@@ -11,13 +11,30 @@
 
 #include <boost/mpl/bool.hpp>
 #include <boost/mpl/apply_fwd.hpp>
-#include <boost/spirit/fusion/sequence/tuple_forward.hpp>
+
+#if	defined BOOST_XPRESSIVE_FUSION_V2
+#	include <boost/fusion/tuple/tuple_fwd.hpp>
+	//version 2 has changed the tag void_t to void_, so this typedef is required
+	namespace boost { namespace fusion
+	{
+		typedef void_ void_t;
+	}}
+	
+	//FUSION_MAX_TUPLE_SIZE was not found by compiler: TODO check if this define is required
+#	if !defined FUSION_MAX_TUPLE_SIZE
+#		define FUSION_MAX_TUPLE_SIZE	FUSION_MAX_VECTOR_SIZE
+#	endif //FUSION_MAX_TUPLE_SIZE
+#else
+#	include <boost/spirit/fusion/sequence/tuple_forward.hpp>
+#endif
+
 #include <boost/preprocessor/repetition/enum_params_with_a_default.hpp>
 
 #ifndef BOOST_PROTO_MAX_ARITY
 # define BOOST_PROTO_MAX_ARITY FUSION_MAX_TUPLE_SIZE
 #endif
 
+
 namespace boost { namespace proto
 {
 
Index: xpressive.hpp
===================================================================
--- xpressive.hpp	(revision 9)
+++ xpressive.hpp	(working copy)
@@ -15,6 +15,12 @@
 # pragma once
 #endif
 
+#if BOOST_VERSION >= 103500
+#	ifndef BOOST_XPRESSIVE_FUSION_V2
+#		define BOOST_XPRESSIVE_FUSION_V2
+#	endif //BOOST_XPRESSIVE_FUSION_V2
+#endif //BOOST_VERSION
+
 #include <boost/xpressive/xpressive_static.hpp>
 #include <boost/xpressive/xpressive_dynamic.hpp>
 
